/*
  This file is part of ut-tweak-tool
  Copyright (C) 2014, 2015 Stefano Verzegnassi

  This program is free software: you can redistribute it and/or modify
  it under the terms of the GNU General Public License 3 as published by
  the Free Software Foundation.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program. If not, see http://www.gnu.org/licenses/.
*/

import QtQuick 2.0
import Ubuntu.Components 1.1

Item {
    anchors.fill: parent

    property string version: "0.1"

    Column {
        anchors {
            top: parent.top
            topMargin: units.gu(6)
            horizontalCenter: parent.horizontalCenter
        }

        width: mainView.width > units.gu(50) ? units.gu(50) : parent.width
        spacing: units.gu(4)

        UbuntuShape {
            id: logo

            width: mainView.width > units.gu(50) ? units.gu(23) : parent.width / 3
            height: width
            radius: "medium"

            image: Image {
                // The x-icon path is relative to the path of Main.qml file
                source: Qt.resolvedUrl("../graphics/match-the-color.png")
            }

            anchors.horizontalCenter: parent.horizontalCenter
        }

        Column {
            width: parent.width

            Label {
                fontSize: "x-large"
                font.weight: Font.DemiBold
                text: manifest.get("title")

                width: parent.width
                horizontalAlignment: Text.AlignHCenter
            }

            Label {
                // TRANSLATORS: Version of the software (e.g. "Version 0.3.51")
                text: i18n.tr("Version %1").arg(manifest.get("version"))

                width: parent.width
                horizontalAlignment: Text.AlignHCenter
            }
        }

        Column {
            width: parent.width

            Label {
                // TRANSLATORS: %1 = Copyright years, %1 = Copyright holder
                // Example of resulting string: "(C) 2014, 2015 John Doe
                text: "(C) %1 %2".arg("2014, 2015")
                                 .arg(manifest.get("maintainer").replace(/<([^<>]*?)>/, ""))

                width: parent.width
                horizontalAlignment: Text.AlignHCenter
            }

            Label {
                fontSize: "small"
                // TRANSLATORS: %1 is the name of the license
                text: i18n.tr("Released under the terms of the %1")
                          .arg("GNU GPL v3")

                width: parent.width
                horizontalAlignment: Text.AlignHCenter
            }
        }

        Column {
            width: parent.width
            spacing: units.gu(2)

            Label {
                fontSize: "small"
                // TRANSLATORS: %1 is the link to the source code, %2 is the hosting service
                // Example: "Source code available on <a href=\https://launchpad.net/match-the-color>launchpad.net</a>"
                text: i18n.tr("Source code available on <a href=\"%1\">%2</a>")
                          .arg("https://launchpad.net/match-the-color")
                          .arg("launchpad.net")

                anchors.horizontalCenter: parent.horizontalCenter

                onLinkActivated: Qt.openUrlExternally(link)
            }
        }
    }
}
