/*
  Copyright (C) 2015 Stefano Verzegnassi

  This program is free software: you can redistribute it and/or modify
  it under the terms of the GNU General Public License 3 as published by
  the Free Software Foundation.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program. If not, see http://www.gnu.org/licenses/.
*/

import QtQuick 2.4
import Ubuntu.Components 1.2
import UserMetrics 0.1
import StorageManager 1.0

MainView {
    id: mainView

    property alias pageStack: pageStack
    PageStack { id: pageStack }

    property alias manifest: manifest
    property alias manifestUrl: manifest.fileUrl
    ManifestParser { id: manifest }

    property url copyrightUrl

    property alias credits: credits
    property alias creditsUrl: credits.fileUrl
    ManifestParser { id: credits }

    property alias classicHighScore: classicHighScore
    HighScoreModel {
        id: classicHighScore
        databaseName: "classichighscore"
    }

    property alias timeAttackHighScore: timeAttackHighScore
    HighScoreModel {
        id: timeAttackHighScore
        databaseName: "timeattackhighscore"
    }

    property alias gameMetric: gameMetric
    Metric {
        id: gameMetric
        name: "match-the-color-metrics"
        // TRANSLATORS: %1 refers to a number of games greater than one.
        // The actual number will be prepended to the string automatically
        // (plural forms are not yet fully supported in usermetrics,
        // the library that displays that string)
        format: i18n.tr("%1 matches played today at Match The Color")
        emptyFormat: i18n.tr("No match played today at Match The Color")
        domain: "com.ubuntu.developer.verzegnassi.match-the-color"
    }

    Component.onCompleted: {
        // Remove old screenshots at start-up
        StorageManager.rm(StorageManager.getXdgFolder(StorageManager.DataLocation) + "/screenshots")
    }
}

