/*
  This file is part of match-the-color
  Copyright (C) 2015 Stefano Verzegnassi

    This program is free software: you can redistribute it and/or modify
  it under the terms of the GNU General Public License 3 as published by
  the Free Software Foundation.

    This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
  along with this program. If not, see http://www.gnu.org/licenses/.
*/

import QtQuick 2.4
import Ubuntu.Components 1.2
import QtQuick.Layouts 1.1

Item {
    id: rootItem
    height: units.gu(6)

    property string title

    function hide()
    {
        anchors.topMargin = -(rootItem.height + divider.height)
    }

    function show()
    {
        anchors.topMargin = 0;
    }

    anchors {
        top: parent.top
        right: parent.right
        left: parent.left
    }

    Behavior on anchors.topMargin {
        UbuntuNumberAnimation { duration: 250 }
    }

    Image {
        anchors {
            right: parent.right
            top: parent.top
            bottom: parent.bottom
        }
        width: units.gu(20)

        fillMode: Image.PreserveAspectCrop
        source: Qt.resolvedUrl("../graphics/origami.png")
    }

    Row {
        anchors {
            fill: parent
            leftMargin: units.gu(2)
            rightMargin: units.gu(2)
        }
        spacing: units.gu(2)

        UbuntuShape {
            id: appIcon
            width: units.gu(5)
            height: width
            anchors.verticalCenter: parent.verticalCenter

            image: Image {
                source: Qt.resolvedUrl("../graphics/match-the-color.png")
            }
        }

        Label {
            text: rootItem.title
            font.weight: Font.Light
            fontSize: "x-large"
            color: Theme.palette.selected.backgroundText
            anchors.verticalCenter: parent.verticalCenter
        }
    }

    Rectangle {
        id: divider
        anchors {
            left: parent.left
            right: parent.right
            top: parent.bottom
        }

        color: "#888888"
        height: units.dp(2)
        opacity: 0.15
    }
}
