/*
  This file is part of match-the-color
  Copyright (C) 2014, 2015 Stefano Verzegnassi

    This program is free software: you can redistribute it and/or modify
  it under the terms of the GNU General Public License 3 as published by
  the Free Software Foundation.

    This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
  along with this program. If not, see http://www.gnu.org/licenses/.
*/

import QtQuick 2.4
import Ubuntu.Components 1.2
import StorageManager 1.0

Item {
    id: rootItem
    anchors.fill: parent

    property alias title: header.title
    property int lastScore
    property bool lastScoreWasTheBestScore

    signal newGameRequested

    function getCurrentDateTime() {
        var currentdate = new Date();
        return Qt.formatDateTime(currentdate, "yyyyMMdd-hhmmss")
    }

    SequentialAnimation{
        running: true
        PropertyAnimation{ target: scoreLabel; property: "opacity"; to: "1"; duration: 1000 }
    }

    CustomHeader { id: header }

    Item {
        anchors {
            top: header.bottom
            left: parent.left
            right: parent.right
            bottom: parent.bottom
            margins: units.gu(2)
            topMargin: units.gu(4)
        }

        // TODO: Use LogoItem
        Item {
            anchors.horizontalCenter: parent.horizontalCenter

            width: Math.min(parent.width, parent.height * 0.5)
            height: width

            Image {
                anchors {
                    fill: parent
                    margins: units.gu(4)
                }

                source: Qt.resolvedUrl("../graphics/splash.png")

                SequentialAnimation on rotation {
                    loops: Animation.Infinite
                    NumberAnimation {
                        from: 0
                        to: 360
                        duration: 10000
                    }
                }
            }


            Column {
                anchors.centerIn: parent
                width: parent.width

                Label {
                    anchors.horizontalCenter: parent.horizontalCenter
                    text: rootItem.lastScoreWasTheBestScore ? i18n.tr("New record") : i18n.tr("Your score")
                }

                Label {
                    id: scoreLabel
                    anchors.horizontalCenter: parent.horizontalCenter
                    font.pixelSize: parent.width / 8
                    font.weight: Font.DemiBold
                    opacity: 0
                    text: rootItem.lastScore
                }
            }
        }
    }

    Item {
        anchors { left: parent.left; right: parent.right; bottom: parent.bottom; bottomMargin: units.gu(2) }
        height: units.gu(8)

        IconButton {
            anchors { left: parent.left; verticalCenter: parent.verticalCenter; margins: units.gu(2) }
            icon.name: "go-previous"
            onClicked: pageStack.pop()
        }

        IconButton {
            anchors.centerIn: parent
            icon.name: "share"
            onClicked: {
                mainView.grabToImage(function(result) {
                    var path = StorageManager.getXdgFolder(StorageManager.DataLocation) + "/screenshots"

                    if (StorageManager.mkPath(path)) {
                        var url = "%1/%2.png".arg(path).arg(rootItem.getCurrentDateTime())
                        result.saveToFile(url);

                        var sharePage = pageStack.push(Qt.resolvedUrl("../ui/SharePage.qml"), { imageUrl: url })
                    }
                });
            }
        }

        IconButton {
            anchors { right: parent.right; verticalCenter: parent.verticalCenter; margins: units.gu(2) }
            icon.name: "reload"
            pressedColor: "#00a300"
            onClicked: rootItem.newGameRequested()
        }
    }
}
