/*
  This file is part of match-the-color
  Copyright (C) 2014, 2015 Stefano Verzegnassi

    This program is free software: you can redistribute it and/or modify
  it under the terms of the GNU General Public License 3 as published by
  the Free Software Foundation.

    This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
  along with this program. If not, see http://www.gnu.org/licenses/.
*/

import QtQuick 2.0
import "Logic.js" as GameLogic

QtObject {
    id: rootItem
    property int colorId: 1
    property int nameId: 1

    property var colorList: GameLogic.colorList
    property int gameMode: 0    // 0=Classic, 1=TimeAttack
    property int score: 0
    property int timeForRound: 5000
    property bool gameOver: false
    signal gameOver
    signal newColor

    function answerIsFalse()
    {
        if (gameMode === 0) {   // Classic mode
            if (!gameOver) {
                if (colorId != nameId) {
                    // Answer is right, so add a point.
                    score ++
                    newQuestion()
                } else {
                    rootItem.gameOver = true
                }
            }
        } else {    // Time Attack mode
            if (!gameOver) {
                if (colorId != nameId) {
                    // Answer is right, so add a point.
                    score ++
                } else {
                    // Answer is wrong, so remove two points.
                    // This is necessary in order to avoid cheats (pressing
                    // multiple time the same button).
                    if (score > 1)
                        score -= 2
                }

                // In timeAttack mode, we still push a new question
                newQuestion()
            }
        }
    }

    function answerIsTrue()
    {
        if (gameMode == 0) {   // Classic mode
            if (!gameOver) {
                if (colorId == nameId) {
                    // Answer is right, so add a point.
                    score ++
                    newQuestion()
                } else {
                    rootItem.gameOver = true
                }
            }
        } else {    // Time Attack mode
            if (!gameOver) {
                if (colorId == nameId) {
                    // Answer is right, so add a point.
                    score ++
                } else {
                    // Answer is wrong, so remove two points.
                    // This is necessary in order to avoid cheats (pressing
                    // multiple time the same button).
                    if (score > 1)
                        score -= 2
                }

                // In timeAttack mode, we still push a new question
                newQuestion()
            }
        }
    }

    function newQuestion()
    {
        // Update the question
        var newColorId, newNameId

        // If for a number of turns between 2 and 7, we had only different
        // colors, set colorId and nameId with the same value.
        if (turnsFromLastSameColors >= (Math.floor(Math.random() * 6) + 2)) {
            console.log("After %1 turns, it's time for using the same color!"
                        .arg(turnsFromLastSameColors))
            colorId = randomColor()
            nameId = colorId

            turnsFromLastSameColors = 0
        } else {
            newColorId = randomColor()
            newNameId = randomColor()

            // Don't push the same color again
            if (newColorId === colorId)
                newColorId = randomColor()
            if (newNameId === nameId)
                newNameId = randomColor()

            colorId = newColorId;
            nameId = newNameId;

            if (colorId == nameId) {
                console.log("After %1 turns, it's time for using the same color!"
                            .arg(turnsFromLastSameColors))
                turnsFromLastSameColors = 0
            } else {
                turnsFromLastSameColors ++
            }
        }

        // Emit a signal. In order to track the time left, we use an animation which start through this signal.
        rootItem.newColor()
    }

    function randomColor()
    {
        if (score > 15)
            // Tier 2 colors are used when score > 15
            return Math.floor(Math.random() * 7)
        else if (score > 30)
            // Tier 3 colors are used when score > 30
            return Math.floor(Math.random() * rootItem.colorList.length)

        return Math.floor(Math.random() * 4)
    }

    property int turnsFromLastSameColors: 0
}
