/*
  This file is part of match-the-color
  Copyright (C) 2014, 2015 Stefano Verzegnassi

    This program is free software: you can redistribute it and/or modify
  it under the terms of the GNU General Public License 3 as published by
  the Free Software Foundation.

    This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
  along with this program. If not, see http://www.gnu.org/licenses/.
*/

import QtQuick 2.4
import Ubuntu.Components 1.2

Item {
    id: gameArea
    anchors.fill: parent

    signal gameOver(var score)

    Keys.onPressed: {
        if (event.key === Qt.Key_X) {
            colors.answerIsFalse()
            event.accepted = true;
        }
        if (event.key === Qt.Key_V) {
            colors.answerIsTrue()
            event.accepted = true;
        }
    }

    // GAME LOGIC
    Timer {
        id: countDownTimer
        property int timeLeft: 30

        interval: 1000
        repeat: true
        running: true

        onTriggered: timeLeft--
        onTimeLeftChanged: {
            if (timeLeft < 1) {
                colors.gameOver = true
            }
        }
    }

    Logic {
        id: colors

        gameMode: 1
        Component.onCompleted: {
            // Reset stats about score.
            // The game logic is automatically reloaded by gameLoader, so there's no need for a reset.
            lastScore = 0
            lastScoreWasTheBestScore = false

            newQuestion()
            // Force gameArea keyboard focus
            gameArea.forceActiveFocus()
        }

        onGameOverChanged: {
            if (gameOver) {
                circularProgressBar.stop()
                gameArea.gameOver(colors.score)
            }
        }

        onNewColor: {
            circularProgressBar.stop()
            circularProgressBar.duration = timeForAnswer()
            circularProgressBar.start()
        }

        function timeForAnswer() {
            if (score <= 5)
                return 3000
            if (score > 5 && score <= 10)
                return 2900
            if (score > 10 && score <= 20)
                return 2800
            if (score > 20 && score <= 30)
                return 2700
            if (score > 30 && score <= 45)
                return 2600

            return 2500
        }
    }

    LogoItem {
        anchors {
            top: parent.top
            margins: units.gu(2)
            horizontalCenter: parent.horizontalCenter
        }

        width: units.gu(8)
        height: units.gu(8)

        Label {
            anchors.centerIn: parent
            text: countDownTimer.timeLeft
        }
    }

    // This circle is used to track the time left.
    CircularProgressBar {
        id: circularProgressBar
        anchors.centerIn: parent
        width: parent.width - units.gu(4)

        Component.onCompleted: start()
        borderColor: colors.colorList[colors.colorId].color
        borderWidth: units.gu(2)

        duration: colors.timeForRound
        onTimeOut: colors.newQuestion()
    }
    Label {
        anchors.centerIn: circularProgressBar
        font.pixelSize: circularProgressBar.height / 10
        text: colors.colorList[colors.nameId].name
        font.capitalization: Font.AllUppercase
        color: circularProgressBar.borderColor
    }

    Item {
        anchors { left: parent.left; right: parent.right; bottom: parent.bottom; margins: units.gu(2) }
        height: units.gu(8)

        IconButton {
            anchors { left: parent.left; verticalCenter: parent.verticalCenter; margins: units.gu(4) }
            icon.name: "close"
            pressedColor: UbuntuColors.red
            onClicked: colors.answerIsFalse()
        }

        IconButton {
            anchors { right: parent.right; verticalCenter: parent.verticalCenter; margins: units.gu(4) }
            icon.name: "ok"
            pressedColor: UbuntuColors.green
            onClicked: colors.answerIsTrue()
        }
    }
}



