/*
  This file is part of match-the-color
  Copyright (C) 2015 Stefano Verzegnassi

    This program is free software: you can redistribute it and/or modify
  it under the terms of the GNU General Public License 3 as published by
  the Free Software Foundation.

    This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
  along with this program. If not, see http://www.gnu.org/licenses/.
*/

import QtQuick 2.4
import Ubuntu.Components 1.2
import QtSystemInfo 5.0
import "../components"

Page {
    id: gamePage

    property int gameMode: 0
    property int lastScore: 0
    property bool lastScoreWasTheBestScore: false

    Component.onCompleted: gameLoader.sourceComponent = countDownComponent

    // Disable screen saver while playing
    ScreenSaver { screenSaverEnabled: false }

    Loader {
        id: gameLoader

        anchors.centerIn: parent
        height: parent.height
        width: mainView.width > units.gu(50) ? units.gu(50) : parent.width
    }

    // *** COMPONENTS
    Component {
        id: countDownComponent

        CountdownItem {
            onTimeExpired: {
                if (gameMode === 0)
                    gameLoader.sourceComponent = classicGameComponent
                else
                    gameLoader.sourceComponent = timeAttackGameComponent
            }
        }
    }

    Component {
        id: classicGameComponent

        ClassicGameItem {
            onGameOver: {
                // Save the score
                gamePage.lastScore = score
                if (gamePage.lastScore > classicHighScore.topScore) {
                    gamePage.lastScoreWasTheBestScore = true;
                }

                if (score > 0)
                    classicHighScore.addScore(score)

                gameLoader.sourceComponent = gameOverComponent
            }
        }
    }

    Component {
        id: timeAttackGameComponent

        TimeAttackGameItem {
            onGameOver: {
                // Save the score
                gamePage.lastScore = score
                if (gamePage.lastScore > timeAttackHighScore.topScore) {
                    gamePage.lastScoreWasTheBestScore = true;
                }

                if (score > 0)
                    timeAttackHighScore.addScore(score)

                gameLoader.sourceComponent = gameOverComponent
            }
        }
    }

    Component {
        id: gameOverComponent

        GameOverItem {
            title: gamePage.gameMode == 0 ? i18n.tr("Classic mode") : i18n.tr("Time attack")
            lastScore: gamePage.lastScore
            lastScoreWasTheBestScore: gamePage.lastScoreWasTheBestScore
            onNewGameRequested: gameLoader.sourceComponent = countDownComponent

            Component.onCompleted: gameMetric.increment()
        }
    }
}
