/*
  This file is part of match-the-color
  Copyright (C) 2015 Stefano Verzegnassi

    This program is free software: you can redistribute it and/or modify
  it under the terms of the GNU General Public License 3 as published by
  the Free Software Foundation.

    This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
  along with this program. If not, see http://www.gnu.org/licenses/.
*/

import QtQuick 2.4
import Ubuntu.Components 1.2
import Ubuntu.Components.Popups 1.0
import QtGraphicalEffects 1.0
import "../components"

Page {
    id: mainPage

    function hide()
    {
        mainPage.opacity = 0
    }

    function show()
    {
        mainPage.opacity = 1
    }

    onActiveChanged: {
        if (active) {
            header.show()
            mainPage.show()
        } else {
            header.hide()
            mainPage.hide()
        }
    }

    opacity: 0
    Behavior on opacity {
        UbuntuNumberAnimation { duration: 250 }
    }

    CustomHeader {
        id: header
        title: "Match the color"
    }

    Column {
        anchors {
            top: header.bottom
            left: parent.left
            right: parent.right
            bottom: parent.bottom
            margins: units.gu(2)
            topMargin: units.gu(4)
        }

        Item {
            height: parent.height * 0.5
            anchors {
                left: parent.left
                right: parent.right
            }

            BigLogoButton {
                anchors.centerIn: parent
                icon.source: Qt.resolvedUrl("../graphics/media-playback-start.svg")
                onClicked: {
                    var gamePicker = PopupUtils.open(gameModePopover)
                    gamePicker.newGameRequested.connect(function() {
                        var gamePage = pageStack.push(Qt.resolvedUrl("GamePage.qml"))
                        gamePage.gameMode = gamePicker.selectedGameModeIndex
                    })
                }
            }
        }

        Item {
            height: parent.height * 0.5
            anchors {
                left: parent.left
                right: parent.right
            }

            Column {
                anchors {
                    left: parent.left
                    right: parent.right
                    verticalCenter: parent.verticalCenter
                }

                spacing: units.gu(2)

                LabelButton {
                    text: i18n.tr("How to play")
                    onClicked: pageStack.push(Qt.resolvedUrl("TutorialPage.qml"))
                }

                LabelButton {
                    text: i18n.tr("High Scores")
                    onClicked: pageStack.push(Qt.resolvedUrl("HighscorePage.qml"))
                }

                LabelButton {
                    text: i18n.tr("About")
                    onClicked: pageStack.push(Qt.resolvedUrl("AboutPage.qml"))
                }
            }
        }
    }

    // *** COMPONENTS
    Component {
        id: gameModePopover

        Popover {
            id: gameModePicker
            contentHeight: containerLayout.childrenRect.height + units.gu(4)
            z: 10

            property int selectedGameModeIndex: 0

            signal newGameRequested(var selectedGameModeIndex)

            Rectangle {
                id: bgOverlay
                anchors.fill: parent
                parent: mainView
                color: "black"
                opacity: 0
                Behavior on opacity {
                    UbuntuNumberAnimation {}
                }
                Component.onCompleted: opacity = 0.25
            }

            Column {
                id: containerLayout
                anchors {
                    left: parent.left
                    top: parent.top
                    right: parent.right
                    margins: units.gu(2)
                }
                spacing: units.gu(3)

                Label {
                    anchors.horizontalCenter: parent.horizontalCenter
                    font.weight: Font.DemiBold
                    fontSize: "large"
                    text: i18n.tr("Choose a game mode")
                }

                Row {
                    anchors.horizontalCenter: parent.horizontalCenter
                    height: units.gu(16)
                    spacing: units.gu(4)

                    GameModeButton {
                        LogoItem {
                            anchors.horizontalCenter: parent.horizontalCenter
                            width: units.gu(10)
                            height: width
                            rotationEnabled: false
                        }

                        text: i18n.tr("Classic mode")
                        selected: gameModePicker.selectedGameModeIndex == 0
                        onClicked: gameModePicker.selectedGameModeIndex = 0
                    }


                    GameModeButton {
                        Image {
                            id: source
                            anchors.horizontalCenter: parent.horizontalCenter
                            width: units.gu(10)
                            height: width
                            source:  Qt.resolvedUrl("../graphics/overlay.png")
                            visible: false
                        }

                        Icon {
                            id: mask
                            anchors.horizontalCenter: parent.horizontalCenter
                            width: units.gu(10)
                            height: width
                            name: "stopwatch-lap"
                            visible: false
                        }

                        OpacityMask {
                            anchors.fill: mask
                            source: source
                            maskSource: mask
                        }

                        text: i18n.tr("Time attack\n(30s)")
                        selected: gameModePicker.selectedGameModeIndex == 1
                        onClicked: gameModePicker.selectedGameModeIndex = 1
                    }
                }

                Button {
                    anchors {
                        left: parent.left
                        right: parent.right
                    }

                    text: i18n.tr("Start game!")
                    color: UbuntuColors.orange
                    onClicked: {
                        PopupUtils.close(gameModePicker)
                        header.hide()
                        mainPage.hide()
                        gameModePicker.newGameRequested(gameModePicker.selectedGameModeIndex)
                    }
                }
            }
        }
    }
}
