/*
  This file is part of match-the-color
  Copyright (C) 2015 Stefano Verzegnassi

    This program is free software: you can redistribute it and/or modify
  it under the terms of the GNU General Public License 3 as published by
  the Free Software Foundation.

    This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
  along with this program. If not, see http://www.gnu.org/licenses/.
*/

import QtQuick 2.4
import Ubuntu.Components 1.2
import Ubuntu.Components.ListItems 1.0 as ListItem
import Ubuntu.Content 1.1
import QtQuick.Layouts 1.1
import "../components"

Page {
    id: sharePage

    title: i18n.tr("Share screenshot")
    property url imageUrl
    property var activeTransfer

    ListView {
        anchors.fill: parent
        clip: true

        header: previewHeader
        model: peerModel.peers
        delegate: appDelegate
        footer: peerModel.peers.length > 0 ? placeHolderFooter : emptyStateFooter
    }

    ContentPeerModel {
        id: peerModel
        contentType: ContentType.Pictures
        handler: ContentHandler.Share
    }

    ContentTransferHint {
        anchors.fill: parent
        activeTransfer: sharePage.activeTransfer
    }

    // *** COMPONENTS
    Component {
        id: appDelegate

        ListItemBase {
            height: units.gu(8)
            onClicked: {
                activeTransfer = modelData.request();
                activeTransfer.items = [ resultComponent.createObject(sharePage, { "url": imageUrl }) ];
                activeTransfer.state = ContentTransfer.Charged;
            }

            RowLayout {
                anchors.fill: parent
                spacing: units.gu(2)

                UbuntuShape {
                    Layout.preferredHeight: units.gu(6)
                    Layout.preferredWidth: height
                    image: Image {
                        sourceSize { width: parent.width; height: parent.height }
                        asynchronous: true
                        cache: false
                        source: "image://content-hub/" + modelData.appId
                        horizontalAlignment: Image.AlignHCenter
                        verticalAlignment: Image.AlignVCenter
                    }
                }
                Label {
                    text: modelData.name || modelData.appId
                    Layout.fillWidth: true
                }
            }
        }
    }

    Component {
        id: previewHeader

        Column {
            anchors { left: parent.left; right: parent.right }
            height: units.gu(28)

            ListItemBase {
                height: units.gu(24)
                Image {
                    anchors {
                        fill: parent
                        margins: units.gu(2)
                    }

                    fillMode: Image.PreserveAspectFit
                    source: sharePage.imageUrl

                    Rectangle {
                        anchors.centerIn: parent
                        height: parent.paintedHeight + units.gu(0.5)
                        width: parent.paintedWidth + units.gu(0.5)
                        color: "black"
                        z: -10
                    }
                }
            }

            ListItem.Header { text: i18n.tr("Share screenshot through...") }
        }
    }

    Component {
        id: emptyStateFooter
        ListItemBase {
            Label {
                anchors.verticalCenter: parent.verticalCenter
                text: i18n.tr("No available service.")
            }
        }
    }

    Component {
        id: placeHolderFooter
        Item {}
    }

    Component {
        id: resultComponent
        ContentItem {}
    }
}
