/*
  This file is part of match-the-color
  Copyright (C) 2014, 2015 Stefano Verzegnassi

    This program is free software: you can redistribute it and/or modify
  it under the terms of the GNU General Public License 3 as published by
  the Free Software Foundation.

    This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
  along with this program. If not, see http://www.gnu.org/licenses/.
*/

import QtQuick 2.4
import Ubuntu.Components 1.2
import "../components"
import QtGraphicalEffects 1.0

Page {
    Item {
        id: gameArea
        anchors.fill: parent

        // GAME LOGIC
        Logic {
            id: colors

            colorId: 1
            nameId: 1
        }

        Label {
            id: tutorialLabel1
            anchors {
                top: parent.top
                bottom: colorNameLabel.top
                horizontalCenter: parent.horizontalCenter
                margins: units.gu(4)
            }

            verticalAlignment: Text.AlignHCenter
            width: circularProgressBar.width / 2
            opacity: 0

            horizontalAlignment: Text.AlignHCenter
            wrapMode: Text.WordWrap
            text: i18n.tr("Does the name of the color match the displayed color?")
        }

        CircularProgressBar {
            id: circularProgressBar
            anchors.centerIn: parent
            width: parent.width - units.gu(4)

            borderColor: colors.colorList[colors.colorId].color
            borderWidth: units.gu(2)

            Component.onCompleted: demo()
        }
        Label {
            id: colorNameLabel
            anchors.centerIn: circularProgressBar
            font.pixelSize: circularProgressBar.height / 10
            text: colors.colorList[colors.nameId].name
            font.capitalization: Font.AllUppercase
            color: circularProgressBar.borderColor
        }

        Item {
            id: continueItem
            anchors { left: parent.left; right: parent.right; bottom: buttons.top; top: circularProgressBar.bottom }

            opacity: 0
            Label {
                anchors.centerIn: parent
                text: i18n.tr("Tap anywhere to continue...")
            }
        }

        Item {
            id: buttons
            anchors { left: parent.left; right: parent.right; bottom: parent.bottom; margins: units.gu(2) }
            height: units.gu(8)

            IconButton {
                id: noButton
                anchors { left: parent.left; verticalCenter: parent.verticalCenter; margins: units.gu(4) }
                icon.name: "close"
            }
            DropShadow {
                id: noButtonShadow
                opacity: 0
                anchors.fill: noButton
                horizontalOffset: 0
                verticalOffset: 0
                radius: 8.0
                samples: 16
                spread: 0.5
                color: noButton.pressedColor
                source: noButton
            }

            IconButton {
                id: yesButton
                anchors { right: parent.right; verticalCenter: parent.verticalCenter; margins: units.gu(4) }
                icon.name: "ok"
                pressedColor: "#00a300"
            }
            DropShadow {
                id: yesButtonShadow
                opacity: 0
                anchors.fill: yesButton
                horizontalOffset: 0
                verticalOffset: 0
                radius: 8.0
                samples: 16
                spread: 0.5
                color: yesButton.pressedColor
                source: yesButton
            }
        }
    }

    property int phase: 0
    MouseArea {
        anchors.fill: parent
        onClicked: goOn()
    }

    SequentialAnimation{
        id: firstQuestionAnimation

        PropertyAnimation{ target: tutorialLabel1; property: "opacity"; to: "1"; duration: 1000 }
        ParallelAnimation {
            // yesButton has already an animation of 100ms: 1000ms = 100 x 100
            PropertyAnimation{ target: yesButton; property: "color"; to: yesButton.pressedColor; duration: 100 }
            PropertyAnimation{ target: yesButtonShadow; property: "opacity"; to: "1"; duration: 1000 }
        }
        PropertyAnimation{ target: continueItem; property: "opacity"; to: "1"; duration: 1000 }
        ScriptAction { script: phase++ }
    }

    SequentialAnimation{
        id: secondQuestionAnimation

        PropertyAnimation{ target: tutorialLabel1; property: "opacity"; to: "1"; duration: 1000 }
        ParallelAnimation {
            // noButton has already an animation of 100ms: 1000ms = 100 x 100
            PropertyAnimation{ target: noButton; property: "color"; to: noButton.pressedColor; duration: 100 }
            PropertyAnimation{ target: noButtonShadow; property: "opacity"; to: "1"; duration: 1000 }
        }
        PropertyAnimation{ target: continueItem; property: "opacity"; to: "1"; duration: 1000 }
        ScriptAction { script: phase++ }
    }

    function goOn() {
        if (phase == 1 && !secondQuestionAnimation.running) {
            colors.colorId = 0
            colors.nameId = 3

            tutorialLabel1.opacity = 0
            yesButton.color = Theme.palette.selected.backgroundText
            yesButtonShadow.opacity = 0
            continueItem.opacity = 0

            secondQuestionAnimation.start()
        }

        if (phase == 2) {
            pageStack.pop()
        }

    }

    Component.onCompleted: firstQuestionAnimation.start()
}
